@@ -23,5 +23,5 @@ def cli(obj, action, ids, query, filters, text):
         total, _, _ = client.get_count(query)
         ids = [a.id for a in client.get_alerts(query)]
 
-    label = 'Action ({}) {} alerts'.format(action, total)
+    label = f'Action ({action}) {total} alerts'
     action_progressbar(client, action=action, ids=ids, label=label, text=text)
