@@ -8,4 +8,4 @@ def cli(obj):
     for k, v in obj.items():
         if isinstance(v, list):
             v = ', '.join(v)
-        click.echo('{:20}: {}'.format(k, v))
+        click.echo(f'{k:20}: {v}')
