@@ -6,7 +6,7 @@ from alertaclient.api import Client
 class AlertTestCase(unittest.TestCase):
 
     def setUp(self):
-        self.client = Client(endpoint='http://api:8080', key='demo-key')
+        self.client = Client(endpoint='http://alerta:8080/api', key='demo-key')
 
     def test_permission(self):
         perm = self.client.create_perm(role='websys', scopes=['admin:users', 'admin:keys', 'write'])
